@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '3.18';
+$VERSION = '3.28';
 
 use Carp                  qw(croak carp);
 use Config                qw(%Config);
@@ -33,6 +33,9 @@ BEGIN {
  *is_linux   = $^O eq 'linux'    ? \&TRUE : \&FALSE unless defined &is_linux;
  *is_hpux    = $^O =~ m/hpux/    ? \&TRUE : \&FALSE unless defined &is_hpux;
  *is_openbsd = $^O =~ m/openbsd/ ? \&TRUE : \&FALSE unless defined &is_openbsd;
+ *is_freebsd = $^O =~ m/freebsd/ ? \&TRUE : \&FALSE unless defined &is_freebsd;
+ *is_bitrig = $^O =~ m/bitrig/ ? \&TRUE : \&FALSE unless defined &is_bitrig;
+ *is_midnightbsd = $^O =~ m/midnightbsd/ ? \&TRUE : \&FALSE unless defined &is_midnightbsd;
 }
 
 sub _perldoc_elem {
@@ -105,7 +108,7 @@ Pod::Perldoc::BaseTo - Base for Pod::Perldoc formatters
 
     package Pod::Perldoc::ToMyFormat;
 
-    use base qw( Pod::Perldoc::BaseTo );
+    use parent qw( Pod::Perldoc::BaseTo );
     ...
 
 =head1 DESCRIPTION
@@ -142,11 +145,10 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
+Current maintainer: brian d foy C<< <briandfoy@pobox.com> >>
 
 Past contributions from:
-brian d foy C<< <bdfoy@cpan.org> >>
-Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
-Sean M. Burke C<< <sburke@cpan.org> >>
+Adriano R. Ferreira C<< <adriano@ferreira.pm> >>,
+Sean M. Burke
 
 =cut
