@@ -4,7 +4,7 @@ use warnings;
 use parent qw(Pod::Perldoc::BaseTo);
 
 use vars qw($VERSION);
-$VERSION = '3.18';
+$VERSION = '3.28';
 
 sub is_pageable        { 1 }
 sub write_with_binmode { 0 }
@@ -45,7 +45,7 @@ sub parse_from_file {
 
 =head1 NAME
 
-Pod::Perldoc::ToANSI - render Pod with ANSI color escapes 
+Pod::Perldoc::ToANSI - render Pod with ANSI color escapes
 
 =head1 SYNOPSIS
 
@@ -85,12 +85,11 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
+Current maintainer: brian d foy C<< <briandfoy@pobox.com> >>
 
 Past contributions from:
-brian d foy C<< <bdfoy@cpan.org> >>
-Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
-Sean M. Burke C<< <sburke@cpan.org> >>
+Adriano R. Ferreira C<< <adriano@ferreira.pm> >>,
+Sean M. Burke
 
 
 =cut
