@@ -1,11 +1,12 @@
-require 5.006;
+require 5.010; # Pod::Man requires this
 package Pod::Perldoc::ToMan;
 use strict;
 use warnings;
 use parent qw(Pod::Perldoc::BaseTo);
+use POSIX qw( WNOHANG );
 
 use vars qw($VERSION);
-$VERSION = '3.18';
+$VERSION = '3.28';
 
 use File::Spec::Functions qw(catfile);
 use Pod::Man 2.18;
@@ -63,7 +64,7 @@ sub init {
 sub _roffer_candidates {
 	my( $self ) = @_;
 
-	if( $self->is_openbsd ) { qw( mandoc groff nroff ) }
+	if( $self->is_openbsd || $self->is_freebsd || $self->is_bitrig || $self->is_midnightbsd ) { qw( mandoc groff nroff ) }
 	else                    { qw( groff nroff mandoc ) }
 	}
 
@@ -136,7 +137,7 @@ sub _get_columns {
 sub _get_podman_switches {
 	my( $self ) = @_;
 
-	my @switches = grep !m/^_/s, keys %$self;
+	my @switches = map { $_, $self->{$_} } grep !m/^_/s, keys %$self;
 
     # There needs to be a cleaner way to handle setting
     # the UTF-8 flag, but for now, comment out this
@@ -146,6 +147,12 @@ sub _get_podman_switches {
     #
     #push @switches, 'utf8' => 1;
 
+    # mandoc handles UTF-8 input just fine.
+	if ( $self->_is_mandoc ) {
+		push @switches, 'utf8' => 1;
+	}
+
+
 	$self->debug( "Pod::Man switches are [@switches]\n" );
 
 	return @switches;
@@ -209,45 +216,22 @@ sub _have_groff_with_utf8 {
 	$version ge $minimum_groff_version;
 	}
 
-sub _have_mandoc_with_utf8 {
-	my( $self ) = @_;
-
-	return 0 unless $self->_is_mandoc;
-	my $roffer = $self->__nroffer;
-
-	my $minimum_mandoc_version = '1.11';
-
-	my $version_string = `$roffer -V`;
-	my( $version ) = $version_string =~ /mandoc ((\d+)\.(\d+))/;
-	$self->debug( "Found mandoc $version\n" );
-
-	# is a string comparison good enough?
-	if( $version lt $minimum_mandoc_version ) {
-		$self->warn(
-			"You have an older mandoc." .
-			" Update to version $minimum_mandoc_version for better Unicode support.\n" .
-			"If you don't upgrade, wide characters may come out oddly.\n" .
-			"Your results still might be odd. If you have groff, that's even better.\n"
-			 );
-		}
-
-	$version ge $minimum_mandoc_version;
-	}
-
 sub _collect_nroff_switches {
 	my( $self ) = shift;
 
-	my @render_switches = $self->_is_mandoc ? qw(-mandoc) : qw(-man);
-
-	push @render_switches, $self->_get_device_switches;
+    my @render_switches = ('-man', $self->_get_device_switches);
 
 	# Thanks to Brendan O'Dea for contributing the following block
-	if( $self->_is_roff and $self->is_linux and -t STDOUT and my ($cols) = $self->_get_columns ) {
+	if( $self->_is_roff and -t STDOUT and my ($cols) = $self->_get_columns ) {
 		my $c = $cols * 39 / 40;
 		$cols = $c > $cols - 2 ? $c : $cols -2;
 		push @render_switches, '-rLL=' . (int $c) . 'n' if $cols > 80;
 		}
 
+	if( $self->_is_mandoc ) {
+		push @render_switches, '-Owidth=' . $self->_get_columns;
+		}
+
 	# I hear persistent reports that adding a -c switch to $render
 	# solves many people's problems.  But I also hear that some mans
 	# don't have a -c switch, so that unconditionally adding it here
@@ -263,7 +247,6 @@ sub _get_device_switches {
 	   if( $self->_is_nroff  )             { qw()              }
 	elsif( $self->_have_groff_with_utf8 )  { qw(-Kutf8 -Tutf8) }
 	elsif( $self->_is_ebcdic )             { qw(-Tcp1047)      }
-	elsif( $self->_have_mandoc_with_utf8 ) { qw(-Tutf8)        }
 	elsif( $self->_is_mandoc )             { qw()              }
 	else                                   { qw(-Tlatin1)      }
 	}
@@ -297,7 +280,7 @@ sub _is_ebcdic {
 
 	return 0;
 	}
-	
+
 sub _filter_through_nroff {
 	my( $self ) = shift;
 	$self->debug( "Filtering through " . $self->__nroffer() . "\n" );
@@ -311,10 +294,10 @@ sub _filter_through_nroff {
     my @render_switches = $self->_collect_nroff_switches;
 
     if ( $switches ) {
-        # Eliminate whitespace 
+        # Eliminate whitespace
         $switches =~ s/\s//g;
 
-        # Then seperate the switches with a zero-width positive 
+        # Then separate the switches with a zero-width positive
         # lookahead on the dash.
         #
         # See:
@@ -379,6 +362,11 @@ sub _filter_through_nroff {
 		length $done
 		);
 
+	my $kid;
+	do {
+        $kid = waitpid(-1, WNOHANG);
+    } while $kid > 0;
+
 	if( $? ) {
 		$self->warn( "Error from pipe to $render!\n" );
 		$self->debug( 'Error: ' . do { local $/; <$err> } );
@@ -571,12 +559,11 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
+Current maintainer: brian d foy C<< <briandfoy@pobox.com> >>
 
 Past contributions from:
-brian d foy C<< <bdfoy@cpan.org> >>
-Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
-Sean M. Burke C<< <sburke@cpan.org> >>
+Adriano R. Ferreira C<< <adriano@ferreira.pm> >>,
+Sean M. Burke
 
 =cut
 
