@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '3.18';
+$VERSION = '3.28';
 
 use parent qw(Pod::Perldoc::BaseTo);
 
@@ -86,13 +86,11 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
+Current maintainer: brian d foy C<< <briandfoy@pobox.com> >>
 
 Past contributions from:
-brian d foy C<< <bdfoy@cpan.org> >>
-Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
-Sean M. Burke C<< <sburke@cpan.org> >>
-
+Adriano R. Ferreira C<< <adriano@ferreira.pm> >>,
+Sean M. Burke
 
 =cut
 
