@@ -6,7 +6,7 @@ use vars qw($VERSION);
 use parent qw( Pod::Simple::XMLOutStream );
 
 use vars qw($VERSION);
-$VERSION = '3.18';
+$VERSION = '3.28';
 
 sub is_pageable        { 0 }
 sub write_with_binmode { 0 }
@@ -52,12 +52,12 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Current maintainer: Mark Allen C<< <mallen@cpan.org> >>
+Current maintainer: brian d foy C<< <briandfoy@pobox.com> >>
 
 Past contributions from:
-brian d foy C<< <bdfoy@cpan.org> >>
-Adriano R. Ferreira C<< <ferreira@cpan.org> >>,
-Sean M. Burke C<< <sburke@cpan.org> >>
+Adriano R. Ferreira C<< <adriano@ferreira.pm> >>,
+Sean M. Burke
+
 
 =cut
 
